@@ -144,11 +144,11 @@ module Gem2Deb
       end
 
       if update
-        new_cache = cache + '.new'
+        new_cache = cache + ".new.#{$$}"
         if system('apt-file search /usr/share/rubygems-integration/ > ' + new_cache)
           if File.stat(new_cache).size > 0
             system('sed', '-i', '-e', 's#/.*/##; s/-[0-9.]\+.gemspec//', new_cache)
-            FileUtils.mv(cache + '.new', cache)
+            FileUtils.mv(new_cache, cache)
           else
             puts 'E: dh-make-ruby needs an up-to-date apt-file cache in order to map gem names'
             puts 'E: to package names but apt-file has an invalid cache. Please run '
